@@ -1,5 +1,5 @@
 ###############################################################################
-# (c) Copyright 2020 CERN for the benefit of the LHCb Collaboration           #
+# (c) Copyright 2020-2022 CERN for the benefit of the LHCb Collaboration      #
 #                                                                             #
 # This software is distributed under the terms of the GNU General Public      #
 # Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
@@ -29,6 +29,11 @@ from .parsing import parse_yaml, render_yaml, validate_yaml
 
 
 def write_jsroot_compression_options(dynamic_dir):
+    """Write options file to configure JSROOT-compatible compression on job output files.
+
+    Args:
+        dynamic_dir: Location to write the use-jsroot-compression.py options file.
+    """
     with open(join(dynamic_dir, "use-jsroot-compression.py"), "wt") as fp:
         fp.write(
             "\n".join(
