@@ -1,5 +1,5 @@
 ###############################################################################
-# (c) Copyright 2021 CERN for the benefit of the LHCb Collaboration           #
+# (c) Copyright 2021-2022 CERN for the benefit of the LHCb Collaboration      #
 #                                                                             #
 # This software is distributed under the terms of the GNU General Public      #
 # Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
@@ -64,7 +64,7 @@ INPUT_SCHEMAS = {
     "bk_query": Map(
         {"bk_query": Str(), Opt("n_test_lfns"): Int(), Opt("dq_flags"): DQ_FLAGS_SCHEMA}
     ),
-    "job_name": Map({"job_name": Str()}),
+    "job_name": Map({"job_name": Str(), Opt("filetype"): Regex(RE_OUTPUT_FILE_TYPE)}),
     "transform_ids": Map(
         {
             "transform_ids": Seq(Int()),
@@ -187,6 +187,19 @@ def _ordered_dict_to_dict(a):
 
 
 def render_yaml(raw_yaml):
+    """Render a "raw" YAML jinja template.
+
+    Accepts LbAP yaml configuration jinja template and renders it into a full YAML configuration.
+
+    Args:
+        raw_yaml (str): YAML jinja-template string
+
+    Raises:
+        ValueError: raised if jinja2 couldn't render the raw_yaml string.
+
+    Returns:
+        str: a jinja-rendered YAML string.
+    """
     try:
         rendered_yaml = jinja2.Template(
             raw_yaml, undefined=jinja2.StrictUndefined
@@ -200,9 +213,17 @@ def render_yaml(raw_yaml):
 
 
 def _validate_proc_pass_map(job_names, proc_pass_map):
-    """
+    """Build processing paths and validate them from a processing pass map.
+
     Given a list of step job names (in correct order), and the processing pass map,
     build the processing path for each step and verify the length is below 100.
+
+    Args:
+        job_names (list[str]): a list containing step job names.
+        proc_pass_map (dict): A dictionary mapping job names to processing pass
+
+    Raises:
+        ValueError: raised if the processing path length is over 100 characters
     """
     for i, job_name in enumerate(job_names):
         proc_passes = map(proc_pass_map.get, job_names[:i] + [job_name])
@@ -225,11 +246,18 @@ def _validate_proc_pass_map(job_names, proc_pass_map):
 
 
 def create_proc_pass_map(job_names, version, default_proc_pass="default"):
-    """
+    """Create a job name to processing pass map.
+
     Given a list of step job names and the production version, produce a
     job_name --> processing pass mapping.
 
-    The processing pass map is validated by _validate_proc_pass_map
+    Args:
+        job_names (list): step job names
+        version (str): LbAPproduction version
+        default_proc_pass (str, optional): the default processing pass. Defaults to "default".
+
+    Returns:
+        dict: a step job name to processing pass map
     """
     proc_pass_prefix = f"AnaProd-{version}-"
     proc_pass_map = {}
@@ -278,11 +306,16 @@ def create_proc_pass_map(job_names, version, default_proc_pass="default"):
 def is_simulation_job(prod_data: dict, job_name: str):
     """Determine if a job is using MC input or not.
 
-    :param prod_data: Entire production information from yaml parsing
-    :param job_name: Name of the job to determine if it's using MC input or not
-    :returns: True if the job is using MC input, False if it is not
-    """
+    Args:
+        prod_data (dict): Entire production information from yaml parsing
+        job_name (str): Name of the job to determine if it's using MC input or not
 
+    Raises:
+        NotImplementedError: No bookkeeping location or job name provided.
+
+    Returns:
+        bool: True if the job is using MC input, False if it is not
+    """
     job_dict = prod_data[job_name]
     if "simulation" not in job_dict:
         if "bk_query" in job_dict["input"]:
@@ -300,6 +333,17 @@ def is_simulation_job(prod_data: dict, job_name: str):
 
 
 def parse_yaml(rendered_yaml):
+    """Parse rendered YAML text.
+
+    Args:
+        rendered_yaml (str): The rendered YAML jinja template.
+
+    Raises:
+        ValueError: raised if errors occurred during parsing.
+
+    Returns:
+        tuple: a tuple of the parsed configuration data2 (dict) and checks data (dict).
+    """
     data1 = load(
         rendered_yaml, schema=MapPattern(Regex(RE_JOB_NAME), Any(), minimum_keys=1)
     )
@@ -465,7 +509,20 @@ def _check_name_magnet_polarity(bk_query, job_name):
 
 
 def validate_yaml(jobs_data, checks_data, repo_root, prod_name):
+    """Validate YAML configuration.
 
+    Args:
+        jobs_data (dict): Parsed job configuration.
+        checks_data (dict): Parsed checks configuration.
+        repo_root (str): Repository location.
+        prod_name (str): Production name.
+
+    Raises:
+        ValueError: Raised if there are showstopper issues in the parsed job configuration.
+
+    Returns:
+        list[str]: warnings (not showstoppers) raised during validation of the configuration.
+    """
     bk_query_to_job = defaultdict(set)
 
     warnings = []
@@ -476,6 +533,7 @@ def validate_yaml(jobs_data, checks_data, repo_root, prod_name):
             _validate_job_data(repo_root, prod_name, job_name, job_data, checks_data)
         except Exception as e:
             raise ValueError(f"Failed to validate {job_name!r} with error {e!r}") from e
+
         if "bk_query" in job_data["input"]:
             if job_data["input"]["bk_query"].lower() in bk_query_to_job:
                 warnings.append(
@@ -483,6 +541,31 @@ def validate_yaml(jobs_data, checks_data, repo_root, prod_name):
                 )
             bk_query_to_job[job_data["input"]["bk_query"].lower()].add(job_name.lower())
 
+        elif "job_name" in job_data["input"]:
+            # Ensire that the job name and output filetype are unambiguously defined
+            if job_data["input"]["job_name"] not in jobs_data:
+                raise ValueError(
+                    f"Unrecognised job name in input: {job_data['input']['job_name']}"
+                )
+            input_job_data = jobs_data[job_data["input"]["job_name"]]
+            input_filetype = job_data["input"].get("filetype", "").upper()
+            if len(input_job_data["output"]) == 1:
+                if input_filetype not in [""] + input_job_data["output"]:
+                    raise ValueError(
+                        f"Unrecognised {input_filetype=} for {job_name=} input, "
+                        f"expected one of: {input_job_data['output']}"
+                    )
+            elif input_filetype == "":
+                raise ValueError(
+                    f"{job_name} gets it's input from a job with multiple outputs. "
+                    "The 'filetype' key must be specified in the 'input' section."
+                )
+            elif input_filetype.upper() not in input_job_data["output"]:
+                raise ValueError(
+                    f"Unrecognised {input_filetype=} for {job_name=} input, "
+                    f"expected one of: {input_job_data['output']}"
+                )
+
     for query, job_set in bk_query_to_job.items():
         for job_name in job_set:
             warnings.extend(_check_name_magnet_polarity(query, job_name))
@@ -599,6 +682,22 @@ def _validate_checks_data(checks_data, jobs_data):
         if not ck_used:
             raise ValueError(f"Check {ck} is defined but not used")
 
+    # Requirements for numbers of bins in checks that create histograms
+    # Must have 1<n<=100  bins on each axis
+    n_bins_maximum = 100
+    for _cname, cdata in checks_data.items():
+        if cdata.get("type") == "range" or cdata.get("type") == "range_bkg_subtracted":
+            if cdata.get("n_bins") <= 1 or cdata.get("n_bins") > n_bins_maximum:
+                raise ValueError(
+                    f"Number of bins for a histogram must be in the interval [2, {n_bins_maximum}]"
+                )
+        elif cdata.get("type") == "range_nd":
+            for _axis, n_bins in cdata.get("n_bins").items():
+                if n_bins <= 1 or n_bins > n_bins_maximum:
+                    raise ValueError(
+                        f"Number of bins for a histogram must be in the interval [2, {n_bins_maximum}] on each axis"
+                    )
+
     # For mean/stddev in range checks: can't specify tolerance without a central value (& vice versa)
     for _cname, cdata in checks_data.items():
         if cdata.get("type") == "range":
