@@ -19,53 +19,81 @@ pytest.importorskip("XRootD")
 
 
 def test_num_entries_passing():
-    result = checks.num_entries(
+    data_in = {
+        "check": {
+            "type": "num_entries",
+            "count": 1000,
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        1000,
-        "DecayTree",
-    )
+    )["check"]
     assert result.passed
     assert result.messages == ["Found 5135823 in DecayTree (1000 required)"]
     assert result.tree_data["DecayTree"]["num_entries"] == 5135823
 
 
 def test_num_entries_passing_multiple_files():
-    result = checks.num_entries(
+    data_in = {
+        "check": {
+            "type": "num_entries",
+            "count": 1000,
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root",
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetUp.root",
         ],
-        1000,
-        "DecayTree",
-    )
+    )["check"]
     assert result.passed
     assert result.messages == ["Found 8556118 in DecayTree (1000 required)"]
     assert result.tree_data["DecayTree"]["num_entries"] == 8556118
 
 
 def test_num_entries_failing():
-    result = checks.num_entries(
+    data_in = {
+        "check": {
+            "type": "num_entries",
+            "count": 1000000000,
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        1000000000,
-        "DecayTree",
-    )
+    )["check"]
     assert not result.passed
     assert result.messages == ["Found 5135823 in DecayTree (1000000000 required)"]
     assert result.tree_data["DecayTree"]["num_entries"] == 5135823
 
 
 def test_num_entries_failing_tree_name():
-    result = checks.num_entries(
+    data_in = {
+        "check": {
+            "type": "num_entries",
+            "count": 1000,
+            "tree_pattern": "RandomName",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        1000000000,
-        "RandomName",
-    )
+    )["check"]
     assert not result.passed
     assert result.messages == ["No TTree objects found that match RandomName"]
     for _key, data in result.tree_data.items():
@@ -73,8 +101,20 @@ def test_num_entries_failing_tree_name():
 
 
 def test_num_entries_per_invpb_passing():
+    data_in = {
+        "check": {
+            "type": "num_entries_per_invpb",
+            "count_per_invpb": 10000,
+            "tree_pattern": "DecayTree",
+            "lumi_pattern": "LumiTuple",
+        }
+    }
     file_list = [Path(__file__).parent.absolute() / "example_tuple_with_lumi.root"]
-    result = checks.num_entries_per_invpb(file_list, 10000, "DecayTree", "LumiTuple")
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
+        file_list,
+    )["check"]
     assert result.passed
     assert result.messages == [
         "Found 23026.2 entries per unit luminosity (pb-1) in DecayTree (10000 required)"
@@ -83,23 +123,43 @@ def test_num_entries_per_invpb_passing():
 
 
 def test_num_entries_per_invpb_failing():
+    data_in = {
+        "check": {
+            "type": "num_entries_per_invpb",
+            "count_per_invpb": 10000000,
+            "tree_pattern": "DecayTree",
+            "lumi_pattern": "LumiTuple",
+        }
+    }
     file_list = [Path(__file__).parent.absolute() / "example_tuple_with_lumi.root"]
-    result = checks.num_entries_per_invpb(file_list, 100000, "DecayTree", "LumiTuple")
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
+        file_list,
+    )["check"]
     assert not result.passed
     assert result.messages == [
-        "Found 23026.2 entries per unit luminosity (pb-1) in DecayTree (100000 required)"
+        "Found 23026.2 entries per unit luminosity (pb-1) in DecayTree (10000000 required)"
     ]
     assert result.tree_data["DecayTree"]["num_entries_per_invpb"] == 23026.2
 
 
 def test_num_entries_per_invpb_failing_MC():
-    result = checks.num_entries_per_invpb(
+    data_in = {
+        "check": {
+            "type": "num_entries_per_invpb",
+            "count_per_invpb": 10000,
+            "tree_pattern": "DecayTree",
+            "lumi_pattern": "LumiTuple",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        10000,
-        "DecayTree",
-    )
+    )["check"]
     assert not result.passed
     assert result.messages == [
         "Failed to get luminosity information (total luminosity = 0)"
@@ -107,13 +167,20 @@ def test_num_entries_per_invpb_failing_MC():
 
 
 def test_num_entries_per_invpb_failing_MC_nameTTree():
-    result = checks.num_entries_per_invpb(
-        [
-            "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
-        ],
-        10000,
-        "RandomName",
-    )
+    data_in = {
+        "check": {
+            "type": "num_entries_per_invpb",
+            "count_per_invpb": 10000,
+            "tree_pattern": "RandomName",
+            "lumi_pattern": "LumiTuple",
+        }
+    }
+    file_list = [Path(__file__).parent.absolute() / "example_tuple_with_lumi.root"]
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
+        file_list,
+    )["check"]
     assert not result.passed
     assert result.messages == [
         "No TTree objects found that match RandomName",
@@ -121,15 +188,23 @@ def test_num_entries_per_invpb_failing_MC_nameTTree():
 
 
 def test_range_check_passing():
-    result = checks.range_check(
+    data_in = {
+        "check": {
+            "type": "range",
+            "expression": "H1_PZ",
+            "limits": {"min": 0.0, "max": 500000.0},
+            "n_bins": 50,
+            "blind_ranges": [],
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        "H1_PZ",
-        {"min": 0.0, "max": 500000.0},
-        [],
-        "DecayTree",
-    )
+    )["check"]
     assert result.passed
     assert result.messages == [
         "Histogram of H1_PZ successfully filled from TTree DecayTree (contains 5134459.0 events)"
@@ -140,16 +215,24 @@ def test_range_check_passing():
 
 
 def test_range_check_passing_multiple_files():
-    result = checks.range_check(
+    data_in = {
+        "check": {
+            "type": "range",
+            "expression": "H1_PZ",
+            "limits": {"min": 0.0, "max": 500000.0},
+            "n_bins": 50,
+            "blind_ranges": [],
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root",
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetUp.root",
         ],
-        "H1_PZ",
-        {"min": 0.0, "max": 500000.0},
-        [],
-        "DecayTree",
-    )
+    )["check"]
     assert result.passed
     assert result.messages == [
         "Histogram of H1_PZ successfully filled from TTree DecayTree (contains 8553802.0 events)"
@@ -160,15 +243,23 @@ def test_range_check_passing_multiple_files():
 
 
 def test_range_check_failing_range():
-    result = checks.range_check(
+    data_in = {
+        "check": {
+            "type": "range",
+            "expression": "H1_PZ",
+            "limits": {"min": -100000.0, "max": -99999.0},
+            "n_bins": 50,
+            "blind_ranges": [],
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        "H1_PZ",
-        {"min": -100000.0, "max": -99999.0},
-        [],
-        "DecayTree",
-    )
+    )["check"]
     assert not result.passed
     assert result.messages == ["No events found in range for Tree DecayTree"]
     assert list(result.tree_data.keys()) == ["DecayTree"]
@@ -177,15 +268,23 @@ def test_range_check_failing_range():
 
 
 def test_range_check_failing_missing_branch():
-    result = checks.range_check(
+    data_in = {
+        "check": {
+            "type": "range",
+            "expression": "Dst_M",
+            "limits": {"min": 1800.0, "max": 2300.0},
+            "n_bins": 50,
+            "blind_ranges": [],
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        "Dst_M",
-        {"min": 1800.0, "max": 2300.0},
-        [],
-        "DecayTree",
-    )
+    )["check"]
     message = result.messages[0]
     pattern = r"Missing branch in "
     matched = False
@@ -199,34 +298,48 @@ def test_range_check_failing_missing_branch():
 
 
 def test_range_check_failing_tree_name():
-    result = checks.range_check(
+    data_in = {
+        "check": {
+            "type": "range",
+            "expression": "H1_PZ",
+            "limits": {"min": 0.0, "max": 500000.0},
+            "n_bins": 50,
+            "blind_ranges": [],
+            "tree_pattern": "RandomName",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        "H1_PZ",
-        {"min": 0.0, "max": 500000.0},
-        [],
-        "RandomName",
-    )
+    )["check"]
     assert not result.passed
     assert result.messages == ["No TTree objects found that match RandomName"]
     assert list(result.tree_data.keys()) == []
 
 
 def test_range_check_failing_bad_mean():
-    result = checks.range_check(
+    data_in = {
+        "check": {
+            "type": "range",
+            "expression": "H1_PZ",
+            "limits": {"min": 0.0, "max": 500000.0},
+            "n_bins": 50,
+            "blind_ranges": [],
+            "tree_pattern": "DecayTree",
+            "exp_mean": 500000.0,
+            "mean_tolerance": 1.0,
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        "H1_PZ",
-        {"min": 0.0, "max": 500000.0},
-        [],
-        "DecayTree",
-        500000.0,
-        0.0,
-        1.0,
-        0.0,
-    )
+    )["check"]
     assert not result.passed
     assert result.messages == [
         "The observed mean (49110.65313794501) differs from the expected value by 450889.346862055 (<=1.0 required)"
@@ -237,19 +350,25 @@ def test_range_check_failing_bad_mean():
 
 
 def test_range_check_failing_bad_stddev():
-    result = checks.range_check(
+    data_in = {
+        "check": {
+            "type": "range",
+            "expression": "H1_PZ",
+            "limits": {"min": 0.0, "max": 500000.0},
+            "n_bins": 50,
+            "blind_ranges": [],
+            "tree_pattern": "DecayTree",
+            "exp_std": 500000.0,
+            "std_tolerance": 1.0,
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        "H1_PZ",
-        {"min": 0.0, "max": 500000.0},
-        [],
-        "DecayTree",
-        0.0,
-        500000.0,
-        0.0,
-        1.0,
-    )
+    )["check"]
     assert not result.passed
     assert result.messages == [
         "The observed standard deviation (53099.76473607609) differs from the expected value by 446900.2352639239 (<=1.0 required)"
@@ -260,19 +379,31 @@ def test_range_check_failing_bad_stddev():
 
 
 def test_range_check_nd_passing():
-    result = checks.range_check_nd(
+    data_in = {
+        "check": {
+            "type": "range_nd",
+            "expressions": {"x": "H1_PZ", "y": "H2_PZ", "z": "H2_PX"},
+            "limits": {
+                "x": {"min": 0.0, "max": 500000.0},
+                "y": {"min": 0.0, "max": 500000.0},
+                "z": {"min": 0.0, "max": 500000.0},
+            },
+            "n_bins": {
+                "x": 50,
+                "y": 50,
+                "z": 50,
+            },
+            "blind_ranges": [],
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        {"x": "H1_PZ", "y": "H2_PZ", "z": "H2_PX"},
-        {
-            "x": {"min": 0.0, "max": 500000.0},
-            "y": {"min": 0.0, "max": 500000.0},
-            "z": {"min": 0.0, "max": 500000.0},
-        },
-        [],
-        "DecayTree",
-    )
+    )["check"]
     assert result.passed
     assert result.messages == [
         "Histogram of H1_PZ, H2_PZ successfully filled from TTree DecayTree (contains 5134453.0 events)",
@@ -285,30 +416,56 @@ def test_range_check_nd_passing():
 
 
 def test_range_check_nd_failing_num_var():
-    result = checks.range_check_nd(
+    data_in = {
+        "check": {
+            "type": "range_nd",
+            "expressions": {"x": "H1_PZ"},
+            "limits": {
+                "x": {"min": 0.0, "max": 500000.0},
+            },
+            "n_bins": {
+                "x": 50,
+                "y": 50,
+            },
+            "blind_ranges": [],
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        {"x": "H1_PZ"},
-        {"x": {"min": 0.0, "max": 500000.0}},
-        [],
-        "DecayTree",
-    )
+    )["check"]
     assert not result.passed
     assert result.messages == ["Expected two or three variables."]
     assert list(result.tree_data.keys()) == []
 
 
 def test_range_check_nd_failing_missing_limit():
-    result = checks.range_check_nd(
+    data_in = {
+        "check": {
+            "type": "range_nd",
+            "expressions": {"x": "H1_PZ", "y": "H2_PZ"},
+            "limits": {
+                "x": {"min": 0.0, "max": 500000.0},
+            },
+            "n_bins": {
+                "x": 50,
+                "y": 50,
+            },
+            "blind_ranges": [],
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        {"x": "H1_PZ", "y": "H2_PZ"},
-        {"x": {"min": 0.0, "max": 500000.0}},
-        [],
-        "DecayTree",
-    )
+    )["check"]
     assert not result.passed
     assert result.messages == [
         "For each variable, a corresponding range should be defined."
@@ -317,15 +474,29 @@ def test_range_check_nd_failing_missing_limit():
 
 
 def test_range_check_nd_failing_missing_branch():
-    result = checks.range_check_nd(
+    data_in = {
+        "check": {
+            "type": "range_nd",
+            "expressions": {"x": "H1_PZ", "y": "Dst_M-D0_M"},
+            "limits": {
+                "x": {"min": 0.0, "max": 500000.0},
+                "y": {"min": 138.0, "max": 150.0},
+            },
+            "n_bins": {
+                "x": 50,
+                "y": 50,
+            },
+            "blind_ranges": [],
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        {"x": "H1_PZ", "y": "Dst_M-D0_M"},
-        {"x": {"min": 0.0, "max": 500000.0}, "y": {"min": 138.0, "max": 150.0}},
-        [],
-        "DecayTree",
-    )
+    )["check"]
     message = result.messages[0]
     pattern = r"Missing branch in "
     matched = False
@@ -339,18 +510,29 @@ def test_range_check_nd_failing_missing_branch():
 
 
 def test_range_check_nd_failing_range():
-    result = checks.range_check_nd(
+    data_in = {
+        "check": {
+            "type": "range_nd",
+            "expressions": {"x": "H1_PZ", "y": "H2_PZ"},
+            "limits": {
+                "x": {"min": -1000000.0, "max": -999999.0},
+                "y": {"min": -1000000.0, "max": -999999.0},
+            },
+            "n_bins": {
+                "x": 50,
+                "y": 50,
+            },
+            "blind_ranges": [],
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        {"x": "H1_PZ", "y": "H2_PZ"},
-        {
-            "x": {"min": -1000000.0, "max": -999999.0},
-            "y": {"min": -1000000.0, "max": -999999.0},
-        },
-        [],
-        "DecayTree",
-    )
+    )["check"]
     assert not result.passed
     assert result.messages == ["No events found in range for Tree DecayTree"]
     assert list(result.tree_data.keys()) == ["DecayTree"]
@@ -359,35 +541,57 @@ def test_range_check_nd_failing_range():
 
 
 def test_range_check_nd_failing_tree_name():
-    result = checks.range_check_nd(
+    data_in = {
+        "check": {
+            "type": "range_nd",
+            "expressions": {"x": "H1_PZ", "y": "H2_PZ"},
+            "limits": {
+                "x": {"min": 0.0, "max": 500000.0},
+                "y": {"min": 0.0, "max": 500000.0},
+            },
+            "n_bins": {
+                "x": 50,
+                "y": 50,
+            },
+            "blind_ranges": [],
+            "tree_pattern": "RandomName",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        {"x": "H1_PZ", "y": "H2_PZ"},
-        {"x": {"min": 0.0, "max": 1.0}, "y": {"min": 0.0, "max": 1.0}},
-        [],
-        "RandomName",
-    )
+    )["check"]
     assert not result.passed
     assert result.messages == ["No TTree objects found that match RandomName"]
     assert list(result.tree_data.keys()) == []
 
 
 def test_range_check_bkg_subtracted_passing():
-    result = checks.range_check_bkg_subtracted(
+    data_in = {
+        "check": {
+            "type": "range_bkg_subtracted",
+            "expression": "D0_PT",
+            "limits": {"min": 0.0, "max": 500000.0},
+            "expr_for_subtraction": "D0_MM",
+            "mean_sig": 1865.0,
+            "background_shift": 30.0,
+            "background_window": 10.0,
+            "signal_window": 20.0,
+            "n_bins": 50,
+            "blind_ranges": {"min": 10000.0, "max": 30000.0},
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/MasterclassDatasets/D0lifetime/2014/MasterclassData.root"
         ],
-        "D0_PT",
-        {"min": 0.0, "max": 500000.0},
-        "D0_MM",
-        1865.0,
-        30.0,
-        10.0,
-        20.0,
-        {"min": 10000.0, "max": 30000.0},
-        "DecayTree",
-    )
+    )["check"]
     assert result.passed
     assert (
         result.messages[0]
@@ -398,20 +602,28 @@ def test_range_check_bkg_subtracted_passing():
 
 
 def test_range_check_bkg_subtracted_failing_range():
-    result = checks.range_check_bkg_subtracted(
+    data_in = {
+        "check": {
+            "type": "range_bkg_subtracted",
+            "expression": "D0_PT",
+            "limits": {"min": -1000000.0, "max": -999999.0},
+            "expr_for_subtraction": "D0_MM",
+            "mean_sig": 1865.0,
+            "background_shift": 30.0,
+            "background_window": 10.0,
+            "signal_window": 20.0,
+            "n_bins": 50,
+            "blind_ranges": {"min": 10000.0, "max": 30000.0},
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/MasterclassDatasets/D0lifetime/2014/MasterclassData.root"
         ],
-        "D0_PT",
-        {"min": -1000000.0, "max": -99999.0},
-        "D0_MM",
-        1865.0,
-        30.0,
-        10.0,
-        20.0,
-        [],
-        "DecayTree",
-    )
+    )["check"]
     assert not result.passed
     assert (
         result.messages[0]
@@ -421,20 +633,28 @@ def test_range_check_bkg_subtracted_failing_range():
 
 
 def test_range_check_bkg_subtracted_failing_missing_branch():
-    result = checks.range_check_bkg_subtracted(
+    data_in = {
+        "check": {
+            "type": "range_bkg_subtracted",
+            "expression": "D0_PT",
+            "limits": {"min": 0.0, "max": 500000.0},
+            "expr_for_subtraction": "Dst_M",
+            "mean_sig": 1865.0,
+            "background_shift": 30.0,
+            "background_window": 10.0,
+            "signal_window": 20.0,
+            "n_bins": 50,
+            "blind_ranges": {"min": 10000.0, "max": 30000.0},
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/MasterclassDatasets/D0lifetime/2014/MasterclassData.root"
         ],
-        "D0_PT",
-        {"min": -1000000.0, "max": -99999.0},
-        "Dst_M",
-        1865.0,
-        30.0,
-        10.0,
-        20.0,
-        [],
-        "DecayTree",
-    )
+    )["check"]
     message = result.messages[0]
     print(message)
     pattern = r"Missing branch in "
@@ -447,45 +667,67 @@ def test_range_check_bkg_subtracted_failing_missing_branch():
 
 
 def test_range_check_bkg_subtracted_failing_tree_name():
-    result = checks.range_check_bkg_subtracted(
+    data_in = {
+        "check": {
+            "type": "range_bkg_subtracted",
+            "expression": "D0_PT",
+            "limits": {"min": 0.0, "max": 500000.0},
+            "expr_for_subtraction": "D0_MM",
+            "mean_sig": 1865.0,
+            "background_shift": 30.0,
+            "background_window": 10.0,
+            "signal_window": 20.0,
+            "n_bins": 50,
+            "blind_ranges": {"min": 10000.0, "max": 30000.0},
+            "tree_pattern": "RandomName",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/MasterclassDatasets/D0lifetime/2014/MasterclassData.root"
         ],
-        "D0_PT",
-        {"min": -1000000.0, "max": -99999.0},
-        "D0_MM",
-        1865.0,
-        30.0,
-        10.0,
-        20.0,
-        [],
-        "RandomName",
-    )
+    )["check"]
     assert not result.passed
     assert result.messages == ["No TTree objects found that match RandomName"]
     assert list(result.tree_data.keys()) == []
 
 
 def test_branches_exist_passing():
-    result = checks.branches_exist(
+    data_in = {
+        "check": {
+            "type": "branches_exist",
+            "branches": ["H1_PZ", "H2_PZ"],
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        ["H1_PZ", "H2_PZ"],
-        "DecayTree",
-    )
+    )["check"]
     assert result.passed
     assert result.messages == ["All required branches were found in Tree DecayTree"]
 
 
 def test_branches_exist_failing_missing_branches():
-    result = checks.branches_exist(
+    data_in = {
+        "check": {
+            "type": "branches_exist",
+            "branches": ["H1_PZ", "H2_PZ", "RandomName"],
+            "tree_pattern": "DecayTree",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        ["H1_PZ", "H2_PZ", "RandomName"],
-        "DecayTree",
-    )
+    )["check"]
     assert not result.passed
     assert result.messages == [
         "Required branches not found in Tree DecayTree: ['RandomName']"
@@ -493,12 +735,19 @@ def test_branches_exist_failing_missing_branches():
 
 
 def test_branches_exist_failing_tree_name():
-    result = checks.branches_exist(
+    data_in = {
+        "check": {
+            "type": "branches_exist",
+            "branches": ["H1_PZ", "H2_PZ"],
+            "tree_pattern": "RandomName",
+        }
+    }
+    result = checks.run_job_checks(
+        ["check"],
+        data_in,
         [
             "root://eospublic.cern.ch//eos/opendata/lhcb/AntimatterMatters2017/data/B2HHH_MagnetDown.root"
         ],
-        ["H1_PZ", "H2_PZ", "RandomName"],
-        "RandomName",
-    )
+    )["check"]
     assert not result.passed
     assert result.messages == ["No TTree objects found that match RandomName"]
