@@ -567,6 +567,7 @@ def test_good_with_checks_no_defaults():
             limits:
                 min: 1750
                 max: 2000
+            n_bins: 40
             blind_ranges:
                 -
                     min: 1850
@@ -590,6 +591,10 @@ def test_good_with_checks_no_defaults():
                 z:
                     min: 3
                     max: 7
+            n_bins:
+                x: 40
+                y: 50
+                z: 60
             blind_ranges:
                 -
                     x:
@@ -607,6 +612,7 @@ def test_good_with_checks_no_defaults():
         check_num_entries_per_invpb:
             type: num_entries_per_invpb
             count_per_invpb: 12.5
+            lumi_pattern: LumiTuple
         check_branches_exist:
             type: branches_exist
             branches:
@@ -656,6 +662,7 @@ def test_good_with_checks_no_defaults():
     assert checks_data["check_range"]["expression"] == "Tuple D0_M"
     assert checks_data["check_range"]["limits"]["min"] == 1750.0
     assert checks_data["check_range"]["limits"]["max"] == 2000.0
+    assert checks_data["check_range"]["n_bins"] == 40
     assert checks_data["check_range"]["blind_ranges"] == [
         {"min": 1850.0, "max": 1880.0},
         {"min": 1900.0, "max": 1910.0},
@@ -673,6 +680,7 @@ def test_good_with_checks_no_defaults():
     }
     assert checks_data["check_range_nd"]["limits"]["y"] == {"min": 139.0, "max": 150.0}
     assert checks_data["check_range_nd"]["limits"]["z"] == {"min": 3.0, "max": 7.0}
+    assert checks_data["check_range_nd"]["n_bins"] == {"x": 40, "y": 50, "z": 60}
     assert checks_data["check_range_nd"]["blind_ranges"] == [
         {
             "x": {"min": 1850.0, "max": 1880.0},
@@ -686,6 +694,7 @@ def test_good_with_checks_no_defaults():
 
     assert checks_data["check_num_entries_per_invpb"]["type"] == "num_entries_per_invpb"
     assert checks_data["check_num_entries_per_invpb"]["count_per_invpb"] == 12.5
+    assert checks_data["check_num_entries_per_invpb"]["lumi_pattern"] == "LumiTuple"
 
     assert checks_data["check_branches_exist"]["type"] == "branches_exist"
     assert checks_data["check_branches_exist"]["branches"] == [
@@ -774,6 +783,7 @@ def test_good_with_checks_defaults_extra_checks():
     assert checks_data["check_range"]["expression"] == "Tuple D0_M"
     assert checks_data["check_range"]["limits"]["min"] == 1750.0
     assert checks_data["check_range"]["limits"]["max"] == 2000.0
+    assert checks_data["check_range"]["n_bins"] == 50
     assert checks_data["check_range"]["blind_ranges"] == [
         {"min": 1850.0, "max": 1880.0},
         {"min": 1900.0, "max": 1910.0},
@@ -783,6 +793,129 @@ def test_good_with_checks_defaults_extra_checks():
     assert checks_data["check_num_entries"]["count"] == 100
 
 
+def test_good_with_checks_defaults_extra_checks_only():
+    rendered_yaml = dedent(
+        """\
+    defaults:
+        application: DaVinci/v45r3
+        wg: Charm
+        inform: a.b@c.d
+
+    checks:
+        check_num_entries:
+            type: num_entries
+            count: 100
+
+    job_1:
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.ROOT
+        options:
+            - options.py
+            - $VAR/a.py
+
+    job_2:
+        input:
+            bk_query: "/MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+        output: FILETYPE.ROOT
+        options:
+            - other_options.py
+        extra_checks:
+            - check_num_entries
+        inform:
+            - other@example.com
+    """
+    )
+    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
+    assert len(jobs_data) == 2
+    assert jobs_data["job_1"]["application"] == "DaVinci/v45r3"
+    assert jobs_data["job_1"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
+    assert jobs_data["job_1"]["output"] == "FILETYPE.ROOT"
+    assert jobs_data["job_1"]["options"] == ["options.py", "$VAR/a.py"]
+    assert jobs_data["job_1"]["wg"] == "Charm"
+    assert jobs_data["job_1"]["automatically_configure"] is False
+    assert jobs_data["job_1"]["turbo"] is False
+    assert jobs_data["job_1"]["inform"] == "a.b@c.d"
+    assert jobs_data["job_1"]["checks"] == []
+
+    assert jobs_data["job_2"]["application"] == "DaVinci/v45r3"
+    assert jobs_data["job_2"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
+    assert jobs_data["job_2"]["output"] == "FILETYPE.ROOT"
+    assert jobs_data["job_2"]["options"] == ["other_options.py"]
+    assert jobs_data["job_2"]["wg"] == "Charm"
+    assert jobs_data["job_2"]["automatically_configure"] is False
+    assert jobs_data["job_2"]["turbo"] is False
+    assert jobs_data["job_2"]["inform"] == ["other@example.com"]
+    assert jobs_data["job_2"]["checks"] == ["check_num_entries"]
+    assert "extra_checks" not in jobs_data["job_2"]
+
+    assert checks_data["check_num_entries"]["type"] == "num_entries"
+    assert checks_data["check_num_entries"]["count"] == 100
+
+
+def test_good_with_checks_nbins_default():
+    rendered_yaml = dedent(
+        """\
+    checks:
+        check_range_nd:
+            type: range_nd
+            expressions:
+                x: Tuple D0_M
+                y: Tuple Dst_M-D0_M
+            limits:
+                x:
+                    min: 1750
+                    max: 2000
+                y:
+                    min: 139
+                    max: 150
+
+    job_1:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.ROOT
+        options:
+            - options.py
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+        checks:
+            - check_range_nd
+    """
+    )
+    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
+    assert len(jobs_data) == 1
+    assert jobs_data["job_1"]["application"] == "DaVinci/v45r3"
+    assert jobs_data["job_1"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
+    assert jobs_data["job_1"]["output"] == "FILETYPE.ROOT"
+    assert jobs_data["job_1"]["options"] == ["options.py", "$VAR/a.py"]
+    assert jobs_data["job_1"]["wg"] == "Charm"
+    assert jobs_data["job_1"]["automatically_configure"] is False
+    assert jobs_data["job_1"]["turbo"] is False
+    assert jobs_data["job_1"]["inform"] == "a.b@c.d"
+    assert jobs_data["job_1"]["checks"] == ["check_range_nd"]
+
+    assert checks_data["check_range_nd"]["type"] == "range_nd"
+    assert checks_data["check_range_nd"]["expressions"] == {
+        "x": "Tuple D0_M",
+        "y": "Tuple Dst_M-D0_M",
+    }
+    assert checks_data["check_range_nd"]["limits"]["x"] == {
+        "min": 1750.0,
+        "max": 2000.0,
+    }
+    assert checks_data["check_range_nd"]["limits"]["y"] == {"min": 139.0, "max": 150.0}
+    assert checks_data["check_range_nd"]["n_bins"] == {"x": 50, "y": 50}
+    assert checks_data["check_range_nd"].get("blind_ranges") is None
+
+
 @pytest.mark.parametrize(
     "missing_key", ["application", "input", "output", "wg", "inform"]
 )
